@@ -40,8 +40,10 @@ void IsotopeGuideView::setVisibleSceneRect(const QPolygonF& sceneRect)
 void IsotopeGuideView::drawForeground(QPainter *painter, const QRectF &rect)
 {
     if (m_guidedView && m_visibleSceneRect.boundingRect().intersects(rect)) {
-        painter->setPen(QPen(Qt::red));
-        painter->drawRect(m_visibleSceneRect.boundingRect().adjusted(0, 0, -1, -1));
+        QRectF drawRect = m_visibleSceneRect.boundingRect().adjusted(0, 0, -1, -1);
+        painter->setPen(QPen(Qt::yellow, 10.0));
+        painter->fillRect(drawRect, QBrush(QColor(0, 0 , 0 , 100)));
+        painter->drawRect(drawRect);
     }
 }
 
@@ -72,8 +74,8 @@ void IsotopeGuideView::mouseReleaseEvent(QMouseEvent *event)
 void IsotopeGuideView::mouseMoveEvent(QMouseEvent *event)
 {
     if (m_dragEvent && event->buttons() & Qt::LeftButton) {
-        QPoint p1(m_guidedView->mapFromScene(mapToScene(m_lastMousePos)));
-        QPoint p2(m_guidedView->mapFromScene(mapToScene(event->pos())));
+        const QPoint p1(m_guidedView->mapFromScene(mapToScene(m_lastMousePos)));
+        const QPoint p2(m_guidedView->mapFromScene(mapToScene(event->pos())));
         m_guidedView->horizontalScrollBar()->setValue(m_guidedView->horizontalScrollBar()->value()
                                                       + p2.x() - p1.x());
         m_guidedView->verticalScrollBar()->setValue(m_guidedView->verticalScrollBar()->value()
